binding_pose_metadynamics.py Command Help

Command: $SCHRODINGER/run -FROM psp binding_pose_metadynamics.py

usage: 
Metadynamics Analysis of Binding Poses
$SCHRODINGER/run -FROM psp binding_pose_metadynamics.py <input complexes> -HOST <CPU Queue> -SUBHOST <GPU Queue>

This algorithm is designed to rank various binding configurations of a single
ligand in a single binding site.

The metadynamics portion of the dynamics will be returned as well as a plot with
the extension -out.pdf which plots the average value of the collective variable
over the simulation

Output Properties:
    r_psp_MetadynamicsBinding_CompScore -- Composite Score linearly combining
        the r_psp_MetadynamicsBinding_PoseScore and
        r_psp_MetadynamicsBinding_Persistence scores.  Lower values equate to
        more stable complexes.  The equation is PoseScore - 5 * Persistence
    r_psp_MetadynamicsBinding_PoseScore -- Expectation of the RMSD of the
        pose over the course of the metadynamics.  Lower values equate to
        more stable complexes.
    r_psp_MetadynamicsBinding_Persistence -- Average persistence of contacts
        over the course of the metadynamics trajectories.  Higher values equate
        to more stable complexes
    r_psp_MetadynamicsBinding_Persistence_HBond -- Average persistence of
        HBonds
    r_psp_MetadynamicsBinding_Persistence_Pi -- Average persistence of Pi-Pi
        stacking and T-Shaped interactions
    r_psp_MetadynamicsBinding_In_RMSD -- Optional RMSD after the relaxation
       step.  This can help identify cases where the relaxation before the
       metadynamics is materially changing the pose

positional arguments:
  struct_file           Structures to process.  These should be Ligand-Receptor
                        complex mae files or pre-equilibrated CMS files.  The most
                        common source for the complex mae files will be the output
                        of IFD runs.  Equilibrated CMS files are designed to be
                        used for systems containing membranes, nucleic acids or
                        any other components that require additional or different
                        equilibration protocols than the default 'relaxation'
                        protocol provided by Desmond which has been designed
                        for soluble proteins.

options:
  -h, --help            show this help message and exit
  -ligand_asl LIGAND_ASL
                        ASL Expression defining the ligand (required).
                        example "res.ptype UNK"
  -nposes NPOSES        Number of poses to re-score.
                        By default all poses are scored but this can be used
                        to score only the first N poses in the input file
  -selected_poses SELECTED_POSES [SELECTED_POSES ...]
                        The entries in the input file to run (or rerun).
                        This value should be 1-indexed.  Note that if you
                        are rerunning a job with the -previous_metadir flag
                        then this will be pose numbers in the output file of
                        the previous run.
  -ntrial NTRIAL        Number of trials per pose (default is 10)
  -anchor_region ANCHOR_REGION
                        ASL expression of the anchor region.  This should be
                        the backbone of 3 to 4 residues in what is thought to be
                        the rigid core of the protein.  This should
                        only be used in combination with 'ligand' cv
  -height HEIGHT        Bias potential height in the metadynamics simulation,
                        unit: kcal/mol, (default is 0.05)
  -restrain RESTRAIN    Whether to use restraints (yes/no default is yes
  -smoothing SMOOTHING  Smoothing constant for CV (default:50)
  -score_fraction SCORE_FRACTION
                        Set the fraction of the CV to use as the score for ranking.
                        0.2 means the last 20 percent will be used.  (Default: 0.2)
  -label_property LABEL_PROPERTY
                        CT-level property to use as a label. Otherwise use
                        the title of the structure
  -run_mode {all,prep,rescore,md,mtd}
                        Modify the mode of binding_pose_metadynamics.
                        all     -- preps runs and scores the subjobs.
                        prep    -- preps the jobs, but does not run them or score the
                                   results.
                        rescore -- for an already completed job, run or re-run the
                                   scoring.
                        md      -- Runs multisim up to and including the unbiased MD
                                   stage. Does not perform the full workflow.
                                   Does not score jobs.
                        mtd     -- Runs the metadyanmics stage. Meant to be run on a
                                   a previous job run with the 'md' run_mode.
                                   Will also perform scoring. The jobname must match
                                   the jobname used with the 'md' run.
                        Note rescore MUST be run with the same settings as the original
                        run.
                        Default: all
  -previous_metadir PREVIOUS_METADIR
                        Add additional trials to an existing
                         BindingPoseMetadynamics run.
                        and with the same settings as the original run.  Note that
                        the output maestro file should be used as the input
  -metadir_basename METADIR_BASENAME
                        Specify the name of the binding pose metadynamics workdir.
                        If this option is not set, the jobname will be used to set the
                        name of the workdir
  -report_md_equil_rmsd
                        For each trial, for each pose, will report the RMSD
                        of the pose immediately after MD equlibration but
                        before any metadynamic repulsion has been applied.
                        This will also produce an additional output file,
                        JOBNAME-mdequil_out.maegz, containing these poses.
                        The RMSDs will also be printed to the logfile.
  -ligand_tail_for_md_equil_rmsd LIGAND_TAIL_FOR_MD_EQUIL_RMSD
                        For -report_md_equil_rmsd ONLY, skip atoms defined by
                        the given SMARTS patterns for the purposes of RMSD calculations.
                        These atoms are considered ligand tails whose positions is not
                        physically relevant
  -no_hmr               Do not use hydrogen mass repartitioning as part of MD
                        Default is to use HMR
  -solvate SOLVATE      Use solvate pocket as part of the multisim workflow
                        (yes/no default is no)
  -cloud PRE_EMPTIBLE_CPU_HOST
                        The argument to -cloud is a pre_emptible CPU host used
                        for the system builder jobs. -SUBHOST will be used
                        exclusively for GPU subjobs and can be a pre-emptible
                        GPU host
  -v                    show program's version number and exit
  -jobname JOBNAME, -JOBNAME JOBNAME, -j JOBNAME
                        Set the base name of outputs

Job Control Options:
  -HOST <hostname>      Run job remotely on the indicated host entry.
  -WAIT                 Do not return a prompt until the job completes.
  -D, -DEBUG            Show details of Job Control operation.
  -NOJOBID              Run the job directly, without Job Control layer.

Standard Options:
  -NJOBS NJOBS          Divide the overall job into NJOBS subjobs.
  -SUBHOST <hostname> or -SUBHOST <hostname:nproc> or -SUBHOST "hostname1:nproc1 ... hostnameN:nprocN"
                        Run the subjobs on the specified hosts. The driver is run on the host specified with -HOST.
  -RETRIES RETRIES      If a subjob fails for any reason, it will be retried RETRIES times. (Default: 2)
  -NOLAUNCH             Set up subjob inputs, but don't run the jobs.